@@ -204,6 +204,11 @@ describe "Sequel::Postgres::JSONOp" do
     @l[@jb.strip_nulls].must_equal "jsonb_strip_nulls(j)"
   end
 
+  it "should have #strip_nulls respect the in_arrays option" do
+    @l[@j.strip_nulls(in_arrays: true)].must_equal "json_strip_nulls(j, true)"
+    @l[@jb.strip_nulls(in_arrays: false)].must_equal "jsonb_strip_nulls(j, false)"
+  end
+
   it "should have #typeof use the json_typeof function" do
     @l[@j.typeof].must_equal "json_typeof(j)"
     @l[@jb.typeof].must_equal "jsonb_typeof(j)"
@@ -237,6 +242,10 @@ describe "Sequel::Postgres::JSONOp" do
     @l[@jb.contain_all(%w'h1')].must_equal "(j ?& ARRAY['h1'])"
   end
 
+  it "#contain_all handle sets" do
+    @l[@jb.contain_all(Set['h1'])].must_equal "(j ?& ARRAY['h1'])"
+  end
+
   it "#contain_any should use the ?| operator" do
     @l[@jb.contain_any(:h1)].must_equal "(j ?| h1)"
   end
@@ -245,6 +254,10 @@ describe "Sequel::Postgres::JSONOp" do
     @l[@jb.contain_any(%w'h1')].must_equal "(j ?| ARRAY['h1'])"
   end
 
+  it "#contain_any should handle sets" do
+    @l[@jb.contain_any(Set['h1'])].must_equal "(j ?| ARRAY['h1'])"
+  end
+
   it "#contains should use the @> operator" do
     @l[@jb.contains(:h1)].must_equal "(j @> h1)"
   end
@@ -450,6 +463,10 @@ describe "Sequel::Postgres::JSONOp" do
     @l[@jb.delete_path(['a'])].must_equal "(j #- ARRAY['a'])"
   end
 
+  it "#delete_path should handle sets" do
+    @l[@jb.delete_path(Set['a'])].must_equal "(j #- ARRAY['a'])"
+  end
+
   it "#has_key? and aliases should use the ? operator" do
     @l[@jb.has_key?('a')].must_equal "(j ? 'a')"
     @l[@jb.include?('a')].must_equal "(j ? 'a')"
